@@ -57,9 +57,9 @@ try:
     # set up the signer info loading the pem and key files
     test_pem = open(pemFile,"rb").read()
     test_key = open(keyFile,"rb").read()
-    sign_info = c2pa.SignerInfo(test_pem, test_key, "es256", "http://timestamp.digicert.com")
+    sign_info = c2pa.SignerInfo("es256", test_pem, test_key, "http://timestamp.digicert.com")
 
-    result = c2pa.add_manifest_to_file_json(testFile, testOutputFile, manifest_json, sign_info, None)
+    result = c2pa.sign_file(testFile, testOutputFile, manifest_json, sign_info, None)
     
 except Exception as err:
     sys.exit(err)
@@ -71,7 +71,7 @@ print("successfully added do not train manifest to file " + testOutputFile)
 
 allowed = True # opt out model, assume training is ok if the assertion doesn't exist
 try:
-    json_store = c2pa.verify_from_file_json(testOutputFile, None)
+    json_store = c2pa.read_file(testOutputFile, None)
     manifest_store = json.loads(json_store)
 
     manifest = manifest_store["manifests"][manifest_store["active_manifest"]]
